API
###

Axis
====

.. autoclass:: xgcm.Axis
   :members:

Grid
====

.. autoclass:: xgcm.Grid
   :members:

Grid ufuncs
====

.. autosummary::
   :toctree: generated/

   xgcm.apply_as_grid_ufunc
   xgcm.as_grid_ufunc

autogenerate
============

.. automodule:: xgcm.autogenerate
  :members:
